searchData={"items":[{"type":"task","title":"mix run_pop3mail","doc":"Retrieve email from a POP3 mailbox.\n\nExamples:\n  * mix run_pop3mail --username=h.lorentz@gmail.com --max 100 --raw\n  * mix run_pop3mail --help","ref":"Mix.Tasks.RunPop3mail.html"},{"type":"function","title":"Mix.Tasks.RunPop3mail.run/1","doc":"","ref":"Mix.Tasks.RunPop3mail.html#run/1"},{"type":"module","title":"Pop3mail","doc":"Download email from the inbox and store them (including attachments) in a subdirectory per email.\n\nReads incoming mail via the POP3 protocol, using an Erlang Epop client with SSL support.\nDecodes multipart content, quoted-printables, base64 and encoded-words.\nThe module also contains functions to perform only the decoding,\ngiving you the choice to do retrieval and storage with your own functions.","ref":"Pop3mail.html"},{"type":"function","title":"Pop3mail.cli/1","doc":"Commandline interface for downloading email and storing them on disk.","ref":"Pop3mail.html#cli/1"},{"type":"function","title":"Examples - Pop3mail.cli/1","doc":"Download maximum 2 emails from the email account and also save the raw undecoded message.\n\n    $ pop3mail_downloader --max=2 --raw --username=hendrik.lorentz@gmail.com --password=secret --output=mailbox\n\n    or\n\n    iex(1)> Pop3mail.cli([\"--max=2\", \"--raw\", \"--username=hendrik.lorentz@gmail.com\", \"--password=secret\", \"--output=mailbox\"])\n    info:  297 emails, 57.643.477 bytes total.\n    info:    Process mail 1: Mon, 13 Oct 2015 18:34:07 +0200\n    info:      message1.txt\n    info:      message2.html\n    info:      Solution Skolem problem.docx\n    info:    Process mail 2: Mon, 13 Oct 2015 19:38:14 +0200\n    info:      message1.iso-8859-1.txt\n    info:      message2.iso-8859-1.html\n    {:ok, 297}\n\n  Print the usage text. It has a long explanation of all the parameters.\n\n    $ pop3mail_downloader --help\n\n    or\n\n    iex(1)> Pop3mail.cli([\"--help\"])\n    usage: ...","ref":"Pop3mail.html#cli/1-examples"},{"type":"function","title":"Pop3mail.decode_body/4","doc":"Decode multipart, base64 and quoted-printable text. Returned is a list of Pop3mail.Part structs.","ref":"Pop3mail.html#decode_body/4"},{"type":"function","title":"Example - Pop3mail.decode_body/4","doc":"Decode message with nested multipart content.\n\n    iex(1)> message = \"\"\"\n    ...(1)> Il s'agit d'un message à parties multiples au format MIME.\n    ...(1)>\n    ...(1)> ------=_NextPart_000_0004_01D0C782.71A41900\n    ...(1)> Content-Type: multipart/alternative;\n    ...(1)> \\tboundary=\"----=_NextPart_001_0005_01D0C782.71A8D3F0\"\n    ...(1)>\n    ...(1)>\n    ...(1)> ------=_NextPart_001_0005_01D0C782.71A8D3F0\n    ...(1)> Content-Type: text/plain;\n    ...(1)> \\tcharset=\"iso-8859-1\"\n    ...(1)> Content-Transfer-Encoding: quoted-printable\n    ...(1)>\n    ...(1)> No problem, the reception will be open until 19.30 tomorrow.\n    ...(1)>\n    ...(1)> T=E9l: 555\n    ...(1)>\n    ...(1)> =20\n    ...(1)>\n    ...(1)>\n    ...(1)> ------=_NextPart_001_0005_01D0C782.71A8D3F0\n    ...(1)> Content-Type: text/html;\n    ...(1)> \\tcharset=\"iso-8859-1\"\n    ...(1)> Content-Transfer-Encoding: quoted-printable\n    ...(1)>\n    ...(1)>   charset=3Diso-8859-1\">\n    ...(1)>    hoi  \n    ...(1)>  \n    ...(1)>  \n    ...(1)>\n    ...(1)>  \n    ...(1)> No problem, the reception will be open until 19.30 =\n    ...(1)> tomorrow. \n    ...(1)>\n    ...(1)>  \n    ...(1)>  \n    ...(1)>  \n    ...(1)>\n    ...(1)> ------=_NextPart_001_0005_01D0C782.71A8D3F0--\n    ...(1)>\n    ...(1)> ------=_NextPart_000_0004_01D0C782.71A41900\n    ...(1)> Content-Type: image/gif;\n    ...(1)> \\tname=\"image001.gif\"\n    ...(1)> Content-Transfer-Encoding: base64\n    ...(1)> Content-ID:  \n    ...(1)>\n    ...(1)> R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7\n    ...(1)>\n    ...(1)> ------=_NextPart_000_0004_01D0C782.71A41900--\n    ...(1)>\n    ...(1)> \"\"\"\n    ...(2)> message |> String.replace(\"\\n\", \"\\r\\n\") |> Pop3mail.decode_body(\"multipart/related; boundary=\\\"----=_NextPart_000_0004_01D0C782.71A41900\\\"\", \"bit7\", \"\")\n    [%Pop3mail.Part{boundary: \"----=_NextPart_001_0005_01D0C782.71A8D3F0\",\n      charset: \"iso-8859-1\",\n      content:  >,\n      content_id: \"\", filename: \"\", filename_charset: \"us-ascii\", index: 1,\n      inline: nil, media_type: \"text/plain\", path: \"related/alternative\"},\n     %Pop3mail.Part{boundary: \"----=_NextPart_001_0005_01D0C782.71A8D3F0\",\n      charset: \"iso-8859-1\",\n      content: \" \\r\\n   hoi  \\r\\n \\r\\n \\r\\n\\r\\n \\r\\nNo problem, the reception will be open until 19.30 tomorrow. \\r\\n\\r\\n \\r\\n \\r\\n \\r\\n\",\n      content_id: \"\", filename: \"\", filename_charset: \"us-ascii\", index: 2,\n      inline: nil, media_type: \"text/html\", path: \"related/alternative\"},\n     %Pop3mail.Part{boundary: \"----=_NextPart_000_0004_01D0C782.71A41900\",\n      charset: \"us-ascii\",\n      content:  >,\n      content_id: \" \", filename: \"image001.gif\",\n      filename_charset: \"us-ascii\", index: 2, inline: nil, media_type: \"image/gif\",\n      path: \"related\"}]","ref":"Pop3mail.html#decode_body/4-example"},{"type":"function","title":"Pop3mail.decode_body_content/2","doc":"Decode multipart, base64 and quoted-printable text. Returned is a list of Pop3mail.Part structs.","ref":"Pop3mail.html#decode_body_content/2"},{"type":"function","title":"Example - Pop3mail.decode_body_content/2","doc":"Retrieve email via epop_client and decode body and close the connection.\n\n    iex(1)> # notice that you must use single quotes here\n    iex(2)> {:ok, client} = :epop_client.connect('user@gmail.com', 'password', [{:addr, 'pop.gmail.com'},{:port,995},{:user, 'user@gmail.com'},:ssl])\n    iex(3)> :epop_client.stat(client)\n    iex(4)> {:ok, mail_content} = :epop_client.bin_retrieve(client, 1)\n    iex(5)> {:message, header_list, body_content } = :epop_message.bin_parse(mail_content)\n    iex(6)> Pop3mail.decode_body_content(header_list, body_content)\n    [%Pop3mail.Part{boundary: \"--_com.android.email_1191110031918720\",\n      charset: \"utf-8\",\n      content: \"\\nPlease give me write access for the forum and possibly the wiki.\\n\\nTIA\\n\",\n      content_id: \"\", filename: \"\", filename_charset: \"us-ascii\", index: 1,\n      inline: nil, media_type: \"text/plain\", path: \"alternative\"},\n     %Pop3mail.Part{boundary: \"--_com.android.email_1191110031918720\",\n      charset: \"utf-8\",\n      content: \"         Please give me write access for the forum and possibly the wiki.     TIA      \",\n      content_id: \"\", filename: \"\", filename_charset: \"us-ascii\", index: 2,\n      inline: nil, media_type: \"text/html\", path: \"alternative\"}]\n    iex(7)> :epop_client.quit(client)","ref":"Pop3mail.html#decode_body_content/2-example"},{"type":"function","title":"Pop3mail.decode_raw_file/2","doc":"Decode raw message file (mostly an .eml file) and store result on disk.\n\nReturns a list with file storage results.","ref":"Pop3mail.html#decode_raw_file/2"},{"type":"function","title":"Example - Pop3mail.decode_raw_file/2","doc":"Decode simple.eml and write result in the testoutput directory.\n\n    iex(1)> Pop3mail.decode_raw_file(\"test/pop3mail/fixtures/simple.eml\", \"testoutput\")\n    info:    Process mail 1: Thu, 4 Sep 2014 19:23:15 +0200\n    info:      message1.iso-8859-1.txt\n    [ok: \"testoutput/20140904_192315_Re_appointment/header.Marie.txt\",\n     ok: \"testoutput/20140904_192315_Re_appointment/message1.iso-8859-1.txt\"]","ref":"Pop3mail.html#decode_raw_file/2-example"},{"type":"function","title":"Pop3mail.decode_words/1","doc":"Decode a text with encoded words as defined in RFC 2047. Returns a list with tuples of charset name and binary content.\n\nEncoded words can occur in email headers (Subject, From, To) and for filenames in multipart content.","ref":"Pop3mail.html#decode_words/1"},{"type":"function","title":"Examples - Pop3mail.decode_words/1","doc":"Russian subject\n\n    iex> Pop3mail.decode_words(\"=?koi8-r?Q?Fwd:_=E4=CF=CD=C1=DB=CE=C5=C5_=DA=C1=C4=C1=CE=C9=C5_?=\")\n    [{\"koi8-r\",\n           >}]\n\n  French (Réception) and ascii text email address\n\n    iex(1)> Pop3mail.decode_words(\"=?iso-8859-1?Q?R=E9ception_Fayence?=  \")\n    [{\"iso-8859-1\",\n           >},\n         {\"us-ascii\", \"  \"}]\n\n  Chinese\n\n    iex(1)> Pop3mail.decode_words(\"chinese\")\n    [{\"us-ascii\", \"chinese\"}]","ref":"Pop3mail.html#decode_words/1-examples"},{"type":"function","title":"Pop3mail.download/1","doc":"Download emails from the inbox and store them (including attachments) in a subdirectory per email.\n\nParameters must be supplied in a string-keyed map:\n* `delete`    - delete email after downloading. Default: false. Notice that Gmail ignores the delete and instead uses the Gmail account settings.\n* `delivered` - true/false. Skip emails with/without Delivered-To header. If you moved an email from your sent box to your inbox it will not have the Delivered-To header. Default: don't skip\n* `max`       - maximum number of emails to download. Default: unlimited\n* `output`    - output directory. Default: inbox\n* `password`  - email account password.\n* `port`      - pop3 server port. Default: 995\n* `raw`       - also save the unprocessed mail in a file called 'raw.eml'. Usefull feature for error diagnostics.\n* `server`    - pop3 server address. Default: pop.gmail.com\n* `ssl`       - true/false. Turn on/off Secure Socket Layer. Default: true\n* `username`  - email account name. Gmail users can precede the name with 'recent:' to get the last 30 days mail, even if it has already been downloaded elsewhere.","ref":"Pop3mail.html#download/1"},{"type":"function","title":"Example - Pop3mail.download/1","doc":"Download maximum 2 emails from the email account and also save the raw undecoded message.\n\n    iex(1)> Pop3mail.download(%{\"max\" => 2, \"raw\" => true, \"username\" => \"hendrik.lorentz@gmail.com\", \"password\" => \"secret\", \"output\" => \"mailbox\"})","ref":"Pop3mail.html#download/1-example"},{"type":"function","title":"Pop3mail.header_lookup/2","doc":"Lookup header in header list retrieved via epop.","ref":"Pop3mail.html#header_lookup/2"},{"type":"function","title":"Example - Pop3mail.header_lookup/2","doc":"Retrieve email via epop_client and lookup headers 'Data', 'Subject' and 'From' and close the connection.\n\n    iex(1)> # notice that you must use single quotes here\n    iex(2)> {:ok, client} = :epop_client.connect('user@gmail.com', 'password', [{:addr, 'pop.gmail.com'},{:port,995},{:user, 'user@gmail.com'},:ssl])\n    iex(3)> :epop_client.stat(client)\n    iex(4)> {:ok, mail_content} = :epop_client.bin_retrieve(client, 1)\n    iex(5)> {:message, header_list, body_content } = :epop_message.bin_parse(mail_content)\n    iex(6)> Pop3mail.header_lookup(header_list, \"Subject\")\n    \"Solution Skolem problem\"\n    iex(7)> Pop3mail.header_lookup(header_list, \"From\")\n    \"Hendrik Lorentz  \"\n    iex(8)> Pop3mail.header_lookup(header_list, \"Date\")\n    \"Thu, 11 Jun 2015 18:05:26 +0000 (UTC)\"\n    iex(9)> :epop_client.quit(client)","ref":"Pop3mail.html#header_lookup/2-example"},{"type":"module","title":"Pop3mail.Base64Decoder","doc":"Replaceable base64 decoder. Replace with your own implementation via the application config :pop3mail, base64_decoder: &lt;replacement&gt;\n\nAfter changing the config/config.exs run:\n* mix deps.compile --force pop3mail","ref":"Pop3mail.Base64Decoder.html"},{"type":"function","title":"Pop3mail.Base64Decoder.decode!/1","doc":"Decode base64 encoded text, ignoring carriage returns and linefeeds. Returns binary.","ref":"Pop3mail.Base64Decoder.html#decode!/1"},{"type":"module","title":"Pop3mail.Base64Decoder.Standard","doc":"Standard Elixir base64 decoder","ref":"Pop3mail.Base64Decoder.Standard.html"},{"type":"function","title":"Pop3mail.Base64Decoder.Standard.decode!/1","doc":"Decode base64 encoded text, ignoring carriage returns and linefeeds. Returns binary.","ref":"Pop3mail.Base64Decoder.Standard.html#decode!/1"},{"type":"module","title":"Pop3mail.Body","doc":"Decode and store mail body","ref":"Pop3mail.Body.html"},{"type":"function","title":"Pop3mail.Body.decode_body/4","doc":"Decode multipart content, base64, quoted-printables","ref":"Pop3mail.Body.html#decode_body/4"},{"type":"function","title":"Pop3mail.Body.store_multiparts/2","doc":"Store all found body parts on filesystem","ref":"Pop3mail.Body.html#store_multiparts/2"},{"type":"function","title":"Pop3mail.Body.store_part/2","doc":"Store one part on filesystem","ref":"Pop3mail.Body.html#store_part/2"},{"type":"module","title":"Pop3mail.CLI","doc":"Commandline interface for downloading emails and storing them on disk.","ref":"Pop3mail.CLI.html"},{"type":"function","title":"Pop3mail.CLI.main/1","doc":"Call main with parameters. E.g. main([\"--username=a.b@gmail.com\", \"--password=secret\"]). Call with --help to get a list of all parameters.","ref":"Pop3mail.CLI.html#main/1"},{"type":"function","title":"Pop3mail.CLI.show_help/0","doc":"print usage line and a description for all parameters.","ref":"Pop3mail.CLI.html#show_help/0"},{"type":"module","title":"Pop3mail.DateConverter","doc":"Date conversions and date utilities","ref":"Pop3mail.DateConverter.html"},{"type":"function","title":"Pop3mail.DateConverter.convert_date/1","doc":"Convert date from email header to a standard date format: YYYYMMDD_HHMMSS\n\n`datestr` - must be conform RFC 2822 date format","ref":"Pop3mail.DateConverter.html#convert_date/1"},{"type":"function","title":"Pop3mail.DateConverter.zero_pad/2","doc":"add zero's at left side of the number","ref":"Pop3mail.DateConverter.html#zero_pad/2"},{"type":"module","title":"Pop3mail.EpopDownloader","doc":"Retrieve and parse POP3 mail via the Epop client.","ref":"Pop3mail.EpopDownloader.html"},{"type":"function","title":"Pop3mail.EpopDownloader.download/1","doc":"Read all emails and save them to disk.\n\n`options` - EpopDownloader.Options","ref":"Pop3mail.EpopDownloader.html#download/1"},{"type":"function","title":"Pop3mail.EpopDownloader.parse_process_and_store/5","doc":"Parse headers, decode body and store everything.\n\n* `mail_content` - string with the complete raw email message.\n* `mail_loop_count` - number of the email in the current session.\n* `delivered` - true/false/nil. Presence, absence or don't care of the 'Delivered-To' email header.\n* `save_raw` - true/false. Save or don't save the raw email message.\n* `output_dir` - directory where all emails are stored.","ref":"Pop3mail.EpopDownloader.html#parse_process_and_store/5"},{"type":"function","title":"Pop3mail.EpopDownloader.retrieve_and_store/3","doc":"Retrieve, parse and store an email.\n\n* `epop_client` - client returned by :epop_client.connect function.\n* `mail_loop_counter` - number of the email in the current session.\n* `options` - EpopDownloader.Options","ref":"Pop3mail.EpopDownloader.html#retrieve_and_store/3"},{"type":"function","title":"Pop3mail.EpopDownloader.retrieve_and_store_all/2","doc":"Read all emails and save them to disk.\n\n* `epop_client` - client returned by :epop_client.connect function.\n* `options` - EpopDownloader.Options","ref":"Pop3mail.EpopDownloader.html#retrieve_and_store_all/2"},{"type":"type","title":"Pop3mail.EpopDownloader.epop_client_type/0","doc":"Epop client from erlpop","ref":"Pop3mail.EpopDownloader.html#t:epop_client_type/0"},{"type":"module","title":"Pop3mail.EpopDownloader.Options","doc":"A struct that holds pop3mail parameter options.\n\nIt's fields are:\n* `cacertfile` - full filename of the CA certifications file. nil = OS CA Certificates.\n* `delete`     - delete email after downloading. Default: false.\n* `delivered`  - true/false/nil. Skip emails with/without/never a Delivered-To header.\n* `max_mails`  - maximum number of emails to download. nil = unlimited\n* `output_dir` - output directory.\n* `password`   - email account password.\n* `port`       - pop3 server port.\n* `save_raw`   - also save the unprocessed mail in a file called 'raw.eml'.\n* `server`     - pop3 server address.\n* `ssl`        - true/false. Turn on/off Secure Socket Layer.\n* `username`   - email account name.\n* `verify`     - true/false. verify certificate of the mailserver.","ref":"Pop3mail.EpopDownloader.Options.html"},{"type":"type","title":"Pop3mail.EpopDownloader.Options.t/0","doc":"","ref":"Pop3mail.EpopDownloader.Options.html#t:t/0"},{"type":"module","title":"Pop3mail.FileStore","doc":"Store header, messages and attachments on the filesystem.","ref":"Pop3mail.FileStore.html"},{"type":"function","title":"Pop3mail.FileStore.dos2unix/1","doc":"Convert a part's content text from dos-format (with carriage return + linefeed after each line) to unix-format (with just the linefeed).\n\n`multipart_part` - a Pop3mail.Part","ref":"Pop3mail.FileStore.html#dos2unix/1"},{"type":"function","title":"Pop3mail.FileStore.get_default_filename/3","doc":"Construct a filename for an email message.\n\nfilename will be: 'message' .   .  \n\nThe default file extenstion for text/plain is .txt\nIn other cases the last part of the `media_type` wil be used as extension.","ref":"Pop3mail.FileStore.html#get_default_filename/3"},{"type":"function","title":"Pop3mail.FileStore.get_line_separator/0","doc":"get line seperator for text files. On windows/dos this is carriage return + linefeed, on other platforms it is just the linefeed.","ref":"Pop3mail.FileStore.html#get_line_separator/0"},{"type":"function","title":"Pop3mail.FileStore.mkdir/3","doc":"make directory. Returns created directory name full path.\n\ndirectory is `base_dir` / `name` - `unsafe_addition`\n\n`unsafe_addition` - append this to the directory name.\nIt will be truncated at 45 characters.\nUnusual characters for the filesystem will be filtered out. If creating the directory with unsafe_addition fails, the directory will be created without it.","ref":"Pop3mail.FileStore.html#mkdir/3"},{"type":"function","title":"Pop3mail.FileStore.remove_unwanted_chars/2","doc":"Remove characters which are undesirable for filesystems (like \\ / : * ? \"   | [ ] and control characters)","ref":"Pop3mail.FileStore.html#remove_unwanted_chars/2"},{"type":"function","title":"Pop3mail.FileStore.set_default_filename/1","doc":"set default filename in the `multipart_part`.\n\nCalls FileStore.get_default_filename to get the default filename.\n\n`multipart_part` - a Pop3mail.Part","ref":"Pop3mail.FileStore.html#set_default_filename/1"},{"type":"function","title":"Pop3mail.FileStore.store_mail_header/4","doc":"Store mail header.\n\nfilename is `filename_prefix` . `unsafe_addition` . txt\n\n`unsafe_addition` - append this to the filename.\nIt will be truncated at 100 characters.\nUnusual characters for the filesystem will be filtered out. If storing with unsafe_addition fails, the file will be stored without it.","ref":"Pop3mail.FileStore.html#store_mail_header/4"},{"type":"function","title":"Pop3mail.FileStore.store_part/2","doc":"store one part of the body.\n\nText files (media types text/plain, text/html for example) will be converted from dos to unix format on non-windows platforms.\n\n`multipart_part` - a Pop3mail.Part. Filenames are truncated at 100 characters.","ref":"Pop3mail.FileStore.html#store_part/2"},{"type":"function","title":"Pop3mail.FileStore.store_raw/3","doc":"store raw email","ref":"Pop3mail.FileStore.html#store_raw/3"},{"type":"module","title":"Pop3mail.Handler","doc":"Glue code for received mail to call the parse, decode and store functions","ref":"Pop3mail.Handler.html"},{"type":"function","title":"Pop3mail.Handler.check_process_and_store/2","doc":"Check if the mail must be skipped, if not process and store the email.\n\nIt checks if the email has or hasn't got the Delivered-To header. Mail could be moved from the sent box to the inbox.\n\n`mail`    - Handler.Mail\n`options` - Handler.Options","ref":"Pop3mail.Handler.html#check_process_and_store/2"},{"type":"function","title":"Pop3mail.Handler.convert_date_to_dirname/1","doc":"Convert date to a directory name meant for storing the email. Returned date is in format yyyymmdd_hhmmss\n\n`date_str` - string with the date. Must be conform RFC 2822 date format.","ref":"Pop3mail.Handler.html#convert_date_to_dirname/1"},{"type":"function","title":"Pop3mail.Handler.decode_body_content/2","doc":"Decode body: multipart content, base64 and quoted-printable.\n\nReturns a list of Pop3mail.Part's.\n\n`header_list` - list with tuples of {:header, header name, header value}.","ref":"Pop3mail.Handler.html#decode_body_content/2"},{"type":"function","title":"Pop3mail.Handler.get_sender_name/1","doc":"Extract the sender name from the email 'From' header.","ref":"Pop3mail.Handler.html#get_sender_name/1"},{"type":"function","title":"Pop3mail.Handler.process_and_store/2","doc":"Create directory for the email based on date and subject, save raw email, store header summary and store everything from the body.\n\n`mail`    - Handler.Mail\n`options` - Handler.Options","ref":"Pop3mail.Handler.html#process_and_store/2"},{"type":"function","title":"Pop3mail.Handler.process_and_store_body/3","doc":"Decode and store body.\n\n`header_list` - list with tuples of {:header, header name, header value}.","ref":"Pop3mail.Handler.html#process_and_store_body/3"},{"type":"function","title":"Pop3mail.Handler.remove_encodings/1","doc":"This function makes sure that the encoding markers are removed and the text decoded.\n\nHowever, it does not convert to a standard encoding like utf-8 and it also doesn't mention the encoding types used.\nWhat you get is a binary which you might be able to read depending on the character encoding set in your terminal/device/program.","ref":"Pop3mail.Handler.html#remove_encodings/1"},{"type":"module","title":"Pop3mail.Handler.Mail","doc":"A struct that holds mail content.\n\nIt's fields are:\n  * `mail_content` - string with the complete raw email content\n  * `mail_loop_counter` - Current number of the email in the retrieval loop. In an POP3 connection each email is numbered, starting at 1.\n  * `header_list` - list with tuples of {:header, header name, header value}.\n  * `body_content` - email body.","ref":"Pop3mail.Handler.Mail.html"},{"type":"type","title":"Pop3mail.Handler.Mail.t/0","doc":"","ref":"Pop3mail.Handler.Mail.html#t:t/0"},{"type":"module","title":"Pop3mail.Handler.Options","doc":"A struct that holds options for the Pop3mail.Handler.\n\nIt's fields are:\n  * `delivered` - true/false/nil. Presence, absence or don't care of the 'Delivered-To' email header.\n  * `save_raw` - true/false. Save or don't save the raw email message.\n  * `base_dir` - directory where the emails must be stored.","ref":"Pop3mail.Handler.Options.html"},{"type":"type","title":"Pop3mail.Handler.Options.t/0","doc":"","ref":"Pop3mail.Handler.Options.html#t:t/0"},{"type":"module","title":"Pop3mail.Header","doc":"Email header related functions.","ref":"Pop3mail.Header.html"},{"type":"function","title":"Pop3mail.Header.lookup/3","doc":"Lookup value by header name. Returns a string.\n\nIf the searched header name occurs multiple times in the list, the result will be the concatenated comma separated value.\n\n`header_list` - list with tuples {:header, header name, value}\n`take`        - Optional parameter to specify maximum number of headers. Negative number takes last header values.","ref":"Pop3mail.Header.html#lookup/3"},{"type":"function","title":"Pop3mail.Header.store/4","doc":"Store email headers Date,From,To,Cc and Subject in a text file.\n\nfilename is `filename_prefix` . `unsafe_addition` . txt\n\n* `header_list` - list with tuples {:header, header name, value}\n* `unsafe_addition` - append this to the filename if the filesystem allows it.","ref":"Pop3mail.Header.html#store/4"},{"type":"module","title":"Pop3mail.Multipart","doc":"Parser for: RFC 2045 Multipart content type (previously RFC 1341).\n\nIt works recursive because a multipart content can contain other multiparts.\nThe returned sequential list of Pop3mail.Path structs is flattened. The Part.path field shows where it is in the hierarchy.\nThis module can also be useful to parse RFC 7578 multipart/form-data (previously RFC 2388).","ref":"Pop3mail.Multipart.html"},{"type":"function","title":"Pop3mail.Multipart.decode/2","doc":"Return decoded text as binary.\n\n`encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.","ref":"Pop3mail.Multipart.html#decode/2"},{"type":"function","title":"Pop3mail.Multipart.decode_base64!/1","doc":"Return decoded text as binary.\n\n`text` - base64 encoded text.","ref":"Pop3mail.Multipart.html#decode_base64!/1"},{"type":"function","title":"Pop3mail.Multipart.decode_lines/2","doc":"Return decoded lines as binary.\n\n`encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.","ref":"Pop3mail.Multipart.html#decode_lines/2"},{"type":"function","title":"Pop3mail.Multipart.extract_and_set_filename/3","doc":"Extract (file-)name from Content-Disposition value or Content-Type value. Returns Pop3mail.Part with filled-in filename and filename_charset.\n\nExample of Content-Disposition header line:\n\n  Content-Disposition: attachment; filename=abc.pdf\n\nRFC 2231 example:\n\n  filename\\*0\\*=us-ascii'en'This%20is%20even%20more%20 \n  filename\\*1\\*=%2A%2A%2Afun%2A%2A%2A%20 \n  filename\\*2=\"isn't it!\"","ref":"Pop3mail.Multipart.html#extract_and_set_filename/3"},{"type":"function","title":"Pop3mail.Multipart.get_param_number/1","doc":"Get parameter number of key_value. `key_value` - format must be: key=value or key* *=value or key*=value. Returns string. Can be empty.","ref":"Pop3mail.Multipart.html#get_param_number/1"},{"type":"function","title":"Pop3mail.Multipart.get_value/1","doc":"Get value of key_value. `key_value` - format must be: key=value or key* *=value or key*=value.","ref":"Pop3mail.Multipart.html#get_value/1"},{"type":"function","title":"Pop3mail.Multipart.is_multipart?/1","doc":"Is this part a multipart? Looks if the media_type starts with multipart/.\n\nIt could be multipart/alternative, multipart/relative or multipart/mixed.\n\n`multipart_part` - Pop3mail.Part","ref":"Pop3mail.Multipart.html#is_multipart?/1"},{"type":"function","title":"Pop3mail.Multipart.lines_continued/2","doc":"A multipart header line can continue on the next line. When next line starts with a tab-character or when there is a opening double quote not closed yet.","ref":"Pop3mail.Multipart.html#lines_continued/2"},{"type":"function","title":"Pop3mail.Multipart.parse_content/1","doc":"Parse multipart content. Returns a flattened list of Pop3mail.Part's\n\nThis is recursively called for each multipart part, e.g. parse_content calls itself\n\n`multipart_part` - Pop3mail.Part input.","ref":"Pop3mail.Multipart.html#parse_content/1"},{"type":"function","title":"Pop3mail.Multipart.parse_content_type/2","doc":"Parse multipart Content-Type header line. It can contain media_type, charset, (file-)name and boundary. Returns a Pop3mail.Part\n\n`multipart_part` - Pop3mail.Part input","ref":"Pop3mail.Multipart.html#parse_content_type/2"},{"type":"function","title":"Pop3mail.Multipart.parse_content_type_parameters/2","doc":"Parse value of content-type header line. It can contain media_type, charset, (file-)name and boundary. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `content_type_parameters` - list of parameters in the format key=value","ref":"Pop3mail.Multipart.html#parse_content_type_parameters/2"},{"type":"function","title":"Pop3mail.Multipart.parse_disposition/2","doc":"Parse multipart Content-Disposition header line. This is either inline or attachment, and it can contain a filename. Returns a Pop3mail.Part\n\n`multipart_part` - Pop3mail.Part input","ref":"Pop3mail.Multipart.html#parse_disposition/2"},{"type":"function","title":"Pop3mail.Multipart.parse_disposition_parameters/2","doc":"Parse value of Content-Disposition header line. This is either inline or attachment, and it can contain a filename. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `disposition_parameters` - list of parameters in the format key=value","ref":"Pop3mail.Multipart.html#parse_disposition_parameters/2"},{"type":"function","title":"Pop3mail.Multipart.parse_multipart/3","doc":"Parse the boundary in the multipart content.\n\n* `raw_content` - multipart content\n* `boundary_name` - multipart boundary to search for\n* `path` - path in the multipart hierarchy. For example: relative/alternative","ref":"Pop3mail.Multipart.html#parse_multipart/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part/3","doc":"Parse a part of the multipart content.\n\n* `{part, index}` - Numbered part content. Index starts at 1 for part 1 in a multipart.\n* `boundary_name` - multipart boundary name\n* `path` - path in the multipart hierarchy. For example: relative/alternative","ref":"Pop3mail.Multipart.html#parse_part/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_content_id/3","doc":"Parse multipart Content-ID header line. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_content_id/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_content_location/3","doc":"Parse multipart Content-Location header line as defined in RFC 2557. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_content_location/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_content_type/3","doc":"Parse multipart Content-Type header line. It can contain media_type, charset, (file-)name and boundary. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_content_type/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_decode/3","doc":"Decode lines and add them as content in the multipart part. Returns a Pop3mail.Part\n\nIs called after all multipart header lines are parsed.\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `lines` - part content splitted in lines","ref":"Pop3mail.Multipart.html#parse_part_decode/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_disposition/3","doc":"Parse multipart Content-Disposition header line. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_disposition/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_finish/3","doc":"Finish parsing multipart header lines and start decode of the part content. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_finish/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_lines/3","doc":"Parse multipart header lines. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_lines/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_skip/3","doc":"Ignore a multipart header line. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_skip/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_transfer_encoding/3","doc":"Parse multipart Content-Transfer-Encoding header line. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_transfer_encoding/3"},{"type":"function","title":"Pop3mail.Multipart.parse_part_unknown_header/3","doc":"Skip an unknown multipart header line. Logs a warning. Returns a Pop3mail.Part\n\n* `multipart_part` - Pop3mail.Part input\n* `encoding` - For example: base64, quoted-printable, 7bit, 8bit, etc.\n* `list` - lines","ref":"Pop3mail.Multipart.html#parse_part_unknown_header/3"},{"type":"module","title":"Pop3mail.Part","doc":"A struct that holds a single part of a multipart, and if there isn't a multipart it contains the email body.\n\nIt's fields are:\n  * `content` - binary with the part's content.\n  * `charset` - character encoding of the content (only applicable for text)\n  * `media_type` - Mime type. Examples: text/plain, text/html, text/rtf, image/jpeg, application/octet-stream\n  * `filename` - binary with filename of the attachment\n  * `filename_charset` - character encoding of the filename\n  * `inline` - true/false/nil. true=inline content, false=attachment, nil=not specified.\n  * `path` - Path within the hierarchy of multipart's. For example: relative/alternative\n  * `index` - Index number of a part within a multipart.\n  * `boundary` - boundary name of the multipart\n  * `content_id` - cid. Generally HTML refers to embedded objects (images mostly) by cid. That is why the related images have a cid.\n  * `content_location` - URI location as defined in RFC 2557.","ref":"Pop3mail.Part.html"},{"type":"type","title":"Pop3mail.Part.t/0","doc":"","ref":"Pop3mail.Part.html#t:t/0"},{"type":"module","title":"Pop3mail.QuotedPrintable","doc":"Decode quoted-printable text as in RFC 2045 # 6.7","ref":"Pop3mail.QuotedPrintable.html"},{"type":"function","title":"Pop3mail.QuotedPrintable.decode/1","doc":"Decode `arg1` string. Returns the result as a character list.","ref":"Pop3mail.QuotedPrintable.html#decode/1"},{"type":"module","title":"Pop3mail.StringUtils","doc":"String manipulation utilities.","ref":"Pop3mail.StringUtils.html"},{"type":"function","title":"Pop3mail.StringUtils.contains?/2","doc":"true if search is found in content","ref":"Pop3mail.StringUtils.html#contains?/2"},{"type":"function","title":"Pop3mail.StringUtils.is_empty?/1","doc":"test if string is nil or has empty length","ref":"Pop3mail.StringUtils.html#is_empty?/1"},{"type":"function","title":"Pop3mail.StringUtils.printable/2","doc":"Print text if it valid utf-8 encoded. If not, print the alternative text.","ref":"Pop3mail.StringUtils.html#printable/2"},{"type":"function","title":"Pop3mail.StringUtils.remove_balanced/2","doc":"Strip a character. Only when it occurs both at the start and end if the text. Strip once only.","ref":"Pop3mail.StringUtils.html#remove_balanced/2"},{"type":"function","title":"Pop3mail.StringUtils.unquoted/1","doc":"Strip double quotes. Only when they occur at the start and end if the text. Strip balanced. Once only.","ref":"Pop3mail.StringUtils.html#unquoted/1"},{"type":"module","title":"Pop3mail.WordDecoder","doc":"Decode words as defined in RFC 2047.","ref":"Pop3mail.WordDecoder.html"},{"type":"function","title":"Pop3mail.WordDecoder.decode_text/1","doc":"Decode a text with possibly encoded-words. Returns a list with tuples {charset, text}. Not encoded text is returned with us-ascii charset.","ref":"Pop3mail.WordDecoder.html#decode_text/1"},{"type":"function","title":"Pop3mail.WordDecoder.decode_word/1","doc":"Decode a word. text with possibly encoded-words. Returns a list with tuples {charset, text}. Not encoded text is returned with us-ascii charset.","ref":"Pop3mail.WordDecoder.html#decode_word/1"},{"type":"function","title":"Pop3mail.WordDecoder.decode_word/2","doc":"Decode a word with the given encoding.\n\n`encoding` - B/Q B=base64 encoded, Q=Quoted-printable","ref":"Pop3mail.WordDecoder.html#decode_word/2"},{"type":"function","title":"Pop3mail.WordDecoder.decoded_text_list_to_string/2","doc":"Concat the text from the decoded list. Does NOT convert to a common character set like utf-8.\n\n* `decoded_text_list` - list with tuples {charset, text}.\n* `add_charset_name` - put the name of the charset after the decoded text parts (when it isn't us-ascii). A hint for the reader if a text contains multiple charsets.","ref":"Pop3mail.WordDecoder.html#decoded_text_list_to_string/2"},{"type":"function","title":"Pop3mail.WordDecoder.get_charsets_besides_ascii/1","doc":"returns sorted unique list of charsets.\n\nBecause the non-encoded text has the us-ascii charset (a subset of utf-8 iso-8859-1 cp1251) we are particulary interested in the other charsets.\n\n`decoded_text_list` - list with tuples {charset, text}.","ref":"Pop3mail.WordDecoder.html#get_charsets_besides_ascii/1"}],"content_type":"text/markdown"}